<?php
/** 
 * Functions for theme Relational Child by Tradesouthwest
 * 
 * Sets up theme defaults and registers support for various WordPress features.
 * @version 1.1.1
 * @since   1.0.0
 */
// ------------------------- Actions ---------------------------
// #A1
add_action( 'after_setup_theme',  'relational_child_theme_setup' ); 
// #A2
add_action( 'wp_enqueue_scripts', 'relational_child_theme_enqueue_styles' );
// #A3
add_action( 'widgets_init',       'relational_child_register_sidebars' );

/** id= A1
 * Child theme to Relational
 *
*/
function relational_child_theme_setup() { 

    add_theme_support( "title-tag" );
    add_theme_support( 'automatic-feed-links' );

    load_theme_textdomain( 'relational-child', 
                            get_stylesheet_directory() . '/languages' ); 

}
/** id= A2
 * Child theme to Relational
 * @uses get_stylesheet_ Parent theme using get_styleshheet so child theme needs 
 *                       to load both parent and child stylesheets.
*/
function relational_child_theme_enqueue_styles() { 

    $parenthandle = 'relational-style'; // This is 'parent-style' theme.
	$theme        = wp_get_theme();
	wp_enqueue_style( $parenthandle,
		get_template_directory_uri() . '/style.css',
		array(),  // If the parent theme code has a dependency, copy it to here.
		$theme->parent()->get( 'Version' )
	);
	wp_enqueue_style( 'relational-child-style',
		get_stylesheet_uri(),
		array( $parenthandle ),
		$theme->get( 'Version' ) // This only works if you have Version defined in the style header.
	);
   
} 

/**
 * Footer sidebar/widget declarations
 *
 * @id A3
 */

function relational_child_register_sidebars() {

    register_sidebar(array(
        'id'            => 'sidemount-sidebar',
        'name'          => __('Widgets inside of Sidemount', 'relational-child'),
        'description'   => __('Used on every page.', 'relational-child'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h4 class="widgettitle">',
        'after_title'   => '</h4>',
    ));
} 
